@@ -21,7 +21,7 @@ use EBox::Model::ModelManager;
 use Socket;
 use Error qw(:try);
 
-use base 'EBox::MigrationBase';
+use base 'EBox::Migration::Base';
 
 
 sub _firewallRulesForObjectsToInternet
