@@ -10,7 +10,7 @@
 #	stored services in firewall
 #
 package EBox::Migration;
-use base 'EBox::MigrationBase';
+use base 'EBox::Migration::Base';
 
 use strict;
 use warnings;
