@@ -54,7 +54,7 @@ sub _create
     my $self =$class->SUPER::_create(
                                      name => 'firewall',
                                      domain => 'ebox-firewall',
-                                     printableName => __('Firewall'),
+                                     printableName => __n('Firewall'),
                                      @_);
     $self->{'ToInternetRuleModel'} =
         new EBox::Firewall::Model::ToInternetRuleTable(
@@ -201,6 +201,13 @@ sub _exposedMethods
 
 }
 
+
+sub restoreDependencies
+{
+    my ($self) = @_;
+    return ['services'];
+}
+
 # utility used by CGI
 
 sub externalIfaceExists
@@ -811,14 +818,14 @@ sub menu
 
     my $folder = new EBox::Menu::Folder('name' => 'Firewall',
                                         'text' => $self->printableName(),
-                                        'separator' => __('UTM'),
+                                        'separator' => 'UTM',
                                         'order' => 310);
 
     $folder->add(new EBox::Menu::Item('url' => 'Firewall/Filter',
                                       'text' => __('Packet Filter')));
 
     $folder->add(new EBox::Menu::Item('url' => 'Firewall/View/RedirectsTable',
-                                      'text' => __('Redirects')));
+                                      'text' => __('Port Forwarding')));
 
     $root->add($folder);
 }
@@ -900,5 +907,45 @@ sub logHelper
     return (new EBox::FirewallLogHelper);
 }
 
+sub consolidateReportQueries
+{
+    return [
+        {
+            'target_table' => 'firewall_report',
+            'query' => {
+                'select' => 'event, fw_src AS source, fw_proto AS proto, fw_dpt AS dport, COUNT(event) AS packets',
+                'from' => 'firewall',
+                'group' => 'event, source, proto, dport'
+            }
+        }
+    ];
+}
+
+sub report
+{
+    my ($self, $beg, $end, $options) = @_;
+
+    my $report = {};
+
+    my $db = EBox::DBEngineFactory::DBEngine();
+
+    $report->{'dropped_packets'} = $self->runMonthlyQuery($beg, $end, {
+        'select' => 'event, SUM(packets) AS packets',
+        'from' => 'firewall_report',
+        'where' => "event = 'drop'",
+        'group' => 'event',
+    }, { 'key' => 'event' } );
+
+    $report->{'top_dropped_sources'} = $self->runQuery($beg, $end, {
+        'select' => 'source, SUM(packets) AS packets',
+        'from' => 'firewall_report',
+        'where' => "event = 'drop'",
+        'group' => 'source',
+        'limit' => $options->{'max_dropped_sources'},
+        'order' => 'packets DESC'
+    });
+
+    return $report;
+}
 
 1;
