@@ -30,14 +30,15 @@ use strict;
 
 use EBox::Model::ModelManager;
 use EBox::Firewall::IptablesRule;
+use EBox::Firewall::IptablesRedirectRule;
 
 use EBox::Exceptions::Internal;
 
-sub new 
+sub new
 {
     my $class = shift;
     my %opts = @_;
-    my $self = {}; 
+    my $self = {};
     $self->{'manager'} = EBox::Model::ModelManager->instance();
     bless($self, $class);
     return $self;
@@ -59,12 +60,13 @@ sub ToInternetRuleTable
             "Cant' get ToInternetRuleTableModel");
 
     my @rules;
-    for my $row (@{$model->rows()}) {
+    for my $id (@{$model->ids()}) {
+        my $row = $model->row($id);
         my $rule = new EBox::Firewall::IptablesRule(
                 'table' => 'filter', 'chain' => 'fglobal');
-        $self->_addAdddressToRule($rule, $row, 'source');
-        $self->_addAdddressToRule($rule, $row, 'destination');
-        $self->_addServiceToRule($rule, $row);  
+        $self->_addAddressToRule($rule, $row, 'source');
+        $self->_addAddressToRule($rule, $row, 'destination');
+        $self->_addServiceToRule($rule, $row);
         $self->_addDecisionToRule($rule, $row);
         push (@rules, @{$rule->strings()});
     }
@@ -74,7 +76,7 @@ sub ToInternetRuleTable
 
 # Method: ExternalToInternalRuleTable
 #
-#   Return iptables rules from 
+#   Return iptables rules from
 #   <EBox::Firewall::Model::ExternalToInternalRuleTable>
 #
 # Returns:
@@ -89,12 +91,13 @@ sub ExternalToInternalRuleTable
             "Cant' get ExternalToInternalRuleTableModel");
 
     my @rules;
-    for my $row (@{$model->rows()}) {
+    for my $id (@{$model->ids()}) {
+        my $row = $model->row($id);
         my $rule = new EBox::Firewall::IptablesRule(
                 'table' => 'filter', 'chain' => 'ffwdrules');
-        $self->_addAdddressToRule($rule, $row, 'source');
-        $self->_addAdddressToRule($rule, $row, 'destination');
-        $self->_addServiceToRule($rule, $row);  
+        $self->_addAddressToRule($rule, $row, 'source');
+        $self->_addAddressToRule($rule, $row, 'destination');
+        $self->_addServiceToRule($rule, $row);
         $self->_addDecisionToRule($rule, $row);
         push (@rules, @{$rule->strings()});
     }
@@ -118,12 +121,13 @@ sub InternalToEBoxRuleTable
             "Cant' get InternalToEBoxRuleTableModel");
 
     my @rules;
-    for my $row (@{$model->rows()}) {
+    for my $id (@{$model->ids()}) {
+        my $row = $model->row($id);
         my $rule = new EBox::Firewall::IptablesRule(
                 'table' => 'filter', 'chain' => 'iglobal');
         $rule->setState('new' => 1);
-        $self->_addAdddressToRule($rule, $row, 'source');
-        $self->_addServiceToRule($rule, $row);  
+        $self->_addAddressToRule($rule, $row, 'source');
+        $self->_addServiceToRule($rule, $row);
         $self->_addDecisionToRule($rule, $row);
         push (@rules, @{$rule->strings()});
     }
@@ -147,12 +151,13 @@ sub ExternalToEBoxRuleTable
             "Cant' get ExternalToEBoxRuleTableModel");
 
     my @rules;
-    for my $row (@{$model->rows()}) {
+    for my $id (@{$model->ids()}) {
+        my $row = $model->row($id);
         my $rule = new EBox::Firewall::IptablesRule(
                 'table' => 'filter', 'chain' => 'iexternal');
         $rule->setState('new' => 1);
-        $self->_addAdddressToRule($rule, $row, 'source');
-        $self->_addServiceToRule($rule, $row);  
+        $self->_addAddressToRule($rule, $row, 'source');
+        $self->_addServiceToRule($rule, $row);
         $self->_addDecisionToRule($rule, $row);
         push (@rules, @{$rule->strings()});
     }
@@ -176,12 +181,13 @@ sub EBoxOutputRuleTable
             "Cant' get EBoxOutputRuleTableModel");
 
     my @rules;
-    for my $row (@{$model->rows()}) {
+    for my $id (@{$model->ids()}) {
+        my $row = $model->row($id);
         my $rule = new EBox::Firewall::IptablesRule(
                 'table' => 'filter', 'chain' => 'oglobal');
         $rule->setState('new' => 1);
-        $self->_addAdddressToRule($rule, $row, 'destination');
-        $self->_addServiceToRule($rule, $row);  
+        $self->_addAddressToRule($rule, $row, 'destination');
+        $self->_addServiceToRule($rule, $row);
         $self->_addDecisionToRule($rule, $row);
         push (@rules, @{$rule->strings()});
     }
@@ -189,20 +195,101 @@ sub EBoxOutputRuleTable
     return \@rules;
 }
 
-sub _addAdddressToRule
+# Method: RedirectsRuleTable
+#
+#   Return iptables rules from <EBox::Firewall::Model::RedirectsTable>
+#
+# Returns:
+#
+#   Array ref of strings containing iptables rules
+sub RedirectsRuleTable
+{
+    my ($self) = @_;
+
+    my $model = $self->{'manager'}->model('RedirectsTable');
+    defined($model) or throw EBox::Exceptions::Internal(
+            "Can't get RedirectsTable Model");
+
+    my @rules;
+    for my $id (@{$model->ids()}) {
+        my $row = $model->row($id);
+        my $rule = new EBox::Firewall::IptablesRedirectRule();
+        $rule->setState('new' => 1);
+        $self->_addIfaceToRule($rule, $row);
+        $self->_addOrigAddressToRule($rule, $row);
+        $self->_addCustomServiceToRule($rule, $row);
+        $self->_addAddressToRule($rule, $row, 'source');
+        $self->_addDestinationToRule($rule, $row);
+        push (@rules, @{$rule->strings()});
+    }
+
+    return \@rules;
+}
+
+sub _addOrigAddressToRule
+{
+    my ($self, $rule, $row) = @_;
+
+    my %params;
+    my $addr = $row->elementByName('origDest');
+    my $type = $addr->selectedType();
+    if ($type  eq 'origDest_ebox') {
+        my $iface = $row->valueByName('interface');
+        my $netModule = EBox::Global->modInstance('network');
+
+        my $extaddr;
+        my $method = $netModule->ifaceMethod($iface);
+        if ($method eq 'dhcp') {
+            $extaddr = $netModule->DHCPAddress($iface);
+        } elsif ($method eq 'static'){
+            $extaddr =  $netModule->ifaceAddress($iface);
+        }
+
+        unless (defined($extaddr) and length($extaddr) > 0) {
+            return;
+        }
+
+        my $addr = new EBox::Types::IPAddr( fieldName => 'ip');
+        $addr->setValue("$extaddr/32");
+        $params{'destinationAddress'} = $addr;
+    } else {
+        if ($type eq 'origDest_ipaddr') {
+            $params{'destinationAddress'} = $addr->subtype();
+        } elsif ($type eq 'origDest_object') {
+            $params{'destinationObject'} = $addr->value();
+        }
+        if ($addr->isa('EBox::Types::InverseMatchUnion')) {
+            $params{'inverseMatch'} = $addr->inverseMatch();
+        }
+    }
+
+    $rule->setDestinationAddress(%params);
+}
+
+sub _addAddressToRule
 {
     my ($self, $rule, $row, $address) = @_;
 
-    my $addr = $row->elementByName($address);
-    my $type = $addr->selectedType();
-
     my %params;
-    if ($type eq $address . '_ipaddr') {
-        $params{$address .'Address'} = $addr->subtype();
-    } elsif ($type eq $address . '_object') {
-        $params{$address . 'Object'} = $addr->value();
+    my $addr = $row->elementByName($address);
+
+    # TODO: It would be nice to have another class to translate
+    # eBox types to iptables params to avoid these checks
+    if ($addr->isa('EBox::Types::Union')) {
+        my $type = $addr->selectedType();
+
+        if ($type eq $address . '_ipaddr') {
+            $params{$address .'Address'} = $addr->subtype();
+        } elsif ($type eq $address . '_object') {
+            $params{$address . 'Object'} = $addr->value();
+        }
+
+        if ($addr->isa('EBox::Types::InverseMatchUnion')) {
+            $params{'inverseMatch'} = $addr->inverseMatch();
+        }
+    } else {
+        $params{$address .'Address'} = $addr;
     }
-    $params{'inverseMatch'} = $addr->inverseMatch();
 
     if ($address eq 'source') {
         $rule->setSourceAddress(%params);
@@ -216,7 +303,59 @@ sub _addServiceToRule
     my ($self, $rule, $row) = @_;
 
     my $service = $row->elementByName('service');
-    $rule->setService($service->value(), $service->inverseMatch());    
+    $rule->setService($service->value(), $service->inverseMatch());
+}
+
+sub _addIfaceToRule
+{
+    my ($self, $rule, $row) = @_;
+
+    my $interface = $row->elementByName('interface');
+    $rule->setInterface($interface->value());
+}
+
+sub _addCustomServiceToRule
+{
+    my ($self, $rule, $row) = @_;
+
+    my ($extPort, $extPortValue, $dstPort, $dstPortValue, $dstPortFilter);
+
+    $extPort = $row->elementByName('external_port');
+    $extPortValue = $extPort->value();
+
+    $dstPort = $row->elementByName('destination_port');
+    if ($dstPort->selectedType() eq 'destination_port_same') {
+        if ($extPort->rangeType() eq 'range') {
+            $dstPortValue = $extPort->from();
+            $dstPortFilter = $extPort->from() . ':' . $extPort->to();
+        } else {
+            $dstPortValue = $extPort->value(); # 'any' or single()
+            $dstPortFilter = $extPort->value();
+        }
+    } else {
+        $dstPortValue = $dstPort->value();
+        if ($extPort->rangeType() eq 'range') {
+            my $endValue = $dstPortValue + ($extPort->to() - $extPort->from());
+            $dstPortFilter = "$dstPortValue:$endValue";
+        } else {
+            $dstPortFilter = $dstPortValue;
+        }
+    }
+
+    my $protocol = $row->elementByName('protocol')->value();
+    $rule->setCustomService($extPortValue, $dstPortValue, $protocol, $dstPortFilter);
+}
+
+sub _addDestinationToRule
+{
+    my ($self, $rule, $row) = @_;
+
+    my $dstAddr = $row->elementByName('destination')->value();
+    my $dstPort = $row->elementByName('destination_port')->value();
+    if ($dstPort eq 'destination_port_same') {
+        $dstPort = undef;
+    }
+    $rule->setDestination($dstAddr, $dstPort);
 }
 
 sub _addDecisionToRule
@@ -225,11 +364,11 @@ sub _addDecisionToRule
 
     my $decision = $row->valueByName('decision');
     if ($decision eq 'accept') {
-        $rule->setDecision('ACCEPT');    
+        $rule->setDecision('ACCEPT');
     } elsif ($decision eq 'deny') {
-        $rule->setDecision('drop');    
+        $rule->setDecision('drop');
     } elsif ($decision eq 'log') {
-        $rule->setDecision('log');    
+        $rule->setDecision('log');
     }
 
 }
