@@ -24,7 +24,7 @@ use EBox::Gettext;
 
 use constant FIREWALL_LOGFILE => '/var/log/syslog';
 
-sub new 
+sub new
 {
         my $class = shift;
         my $self = {};
@@ -32,12 +32,12 @@ sub new
         return $self;
 }
 
-sub domain { 
+sub domain {
         return 'ebox-firewall';
 }
 
 
-# Method: logFiles 
+# Method: logFiles
 #
 #	This function must return the file or files to be read from.
 #
@@ -47,10 +47,10 @@ sub domain {
 #
 sub logFiles
 {
-	return [FIREWALL_LOGFILE];	
+	return [FIREWALL_LOGFILE];
 }
 
-# Method: processLine 
+# Method: processLine
 #
 #	This fucntion will be run every time a new line is recieved in
 #	the associated file. You must parse the line, and generate
@@ -62,8 +62,8 @@ sub logFiles
 #	file - file name
 # 	line - string containing the log line
 #	dbengine- An instance of class implemeting AbstractDBEngineinterface
-# 	
-sub processLine # (file, line, logger) 
+#
+sub processLine # (file, line, logger)
 {
 	my ($self, $file, $line, $dbengine) = @_;
 
@@ -88,7 +88,7 @@ sub processLine # (file, line, logger)
 		if (exists $fields{$uName}) {
 			$dataToInsert{'fw_' . $name} = $fields{$uName};
 		} else {
-			$dataToInsert{'fw_' . $name} = '';
+			$dataToInsert{'fw_' . $name} = undef;
 		}
 	}
 
